/*
(c) 2001-2019 various contributors (see LICENSE)
(c) 2020 Pascal R. G. Abresch (MIT License)
*/

#include "ContactInfoWindow.h"

#include <interface/Button.h>

#include "support/AppLocation.h"

#include "ui/PictureView.h"

#include "jabber/GenericFunctions.h"
#include "jabber/Messages.h"

#include "GroupLayout.h"
#include "GroupLayoutBuilder.h"
#include "StringView.h"

ContactInfoWindow::ContactInfoWindow(UserID *queryingUser)
	: BWindow(BRect(0, 0, 0, 0), "User Information", B_TITLED_WINDOW,
		B_AUTO_UPDATE_SIZE_LIMITS | B_NOT_ZOOMABLE) {
	BRect rect;

	rect = GenericFunctions::CenteredFrame(440, 165);
	MoveTo(rect.LeftTop());

	BStringView *nicknameLabel, *nicknameValue;
	BStringView *XMPPIdLabel, *XMPPIdValue;
	BStringView *statusLabel, *statusValue;
	BStringView *customStatusLabel = NULL, *customStatusValue = NULL;

	auto name = "<Not Set>";
	if (!queryingUser->FriendlyName().empty())
		name = queryingUser->FriendlyName().c_str();

	nicknameValue  = new BStringView("name", name, B_WILL_DRAW);
	nicknameLabel = new BStringView("nick", "Nickname:", B_WILL_DRAW);

	auto customStatus = "<Not Set>";

	if (!queryingUser->MoreExactOnlineStatus().empty())
		customStatus = queryingUser->MoreExactOnlineStatus().c_str();

	customStatusValue  = new BStringView("statusCostumLabel", customStatus, B_WILL_DRAW);
	customStatusLabel = new BStringView("statusCostumValue", "Custom Status:", B_WILL_DRAW);

	auto officalStatus = "<Not Set>";

	if (queryingUser->ExactOnlineStatus() == "xa") {
			officalStatus = "Extended Away";
	} else if (queryingUser->ExactOnlineStatus() == "away") {
			officalStatus = "Away";
	} else if (queryingUser->ExactOnlineStatus() == "chat") {
			officalStatus = "Available for Chat";
	} else if (queryingUser->ExactOnlineStatus() == "dnd") {
			officalStatus = "Do Not Disturb";
	}

	statusValue  = new BStringView("statusValue" , officalStatus, B_WILL_DRAW);
	statusLabel = new BStringView("statusLabel", "Official Status:", B_WILL_DRAW);

	XMPPIdLabel = new BStringView("XMPPIdLabel", "Jabber ID:");
	XMPPIdValue  = new BStringView("XMPPIdValue", queryingUser->Handle().c_str());

	BButton *okButton = new BButton("ok", "OK", new BMessage(JAB_OK));

	okButton->MakeDefault(true);
	okButton->SetTarget(this);

	SetLayout(new BGroupLayout(B_VERTICAL));
	AddChild(BGroupLayoutBuilder(B_VERTICAL, 2)
		.Add(BGroupLayoutBuilder(B_HORIZONTAL, 2)
			.Add(BGroupLayoutBuilder(B_VERTICAL, 4)
				.Add(nicknameLabel)
				.Add(XMPPIdLabel)
				.Add(statusLabel)
				.Add(customStatusLabel))
			.Add(BGroupLayoutBuilder(B_VERTICAL, 4)
				.Add(nicknameValue)
				.Add(XMPPIdValue)
				.Add(statusValue)
				.Add(customStatusValue)))
		.Add(okButton));
}


ContactInfoWindow::~ContactInfoWindow() {

}


void ContactInfoWindow::MessageReceived(BMessage *msg) {
	switch(msg->what) {
		case JAB_OK: {
			PostMessage(B_QUIT_REQUESTED);
			break;
		}
	}
}
